KeysStorageSharedPrefs class

Inheritance
  • Object
  • KeysStorage
  • KeysStorageSharedPrefs

Constructors

KeysStorageSharedPrefs()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String instance) FutureOr<String?>
Returns Serialized key
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String instance) FutureOr<void>
override
set(String instance, String serializedKey) FutureOr<void>
The serializedKey is sensitive, and may be stored encrypted.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited