RegistrationsStorageSharedPrefs class
- Inheritance
-
- Object
- RegistrationsStorage
- RegistrationsStorageSharedPrefs
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getFromInstance(
String instance) → FutureOr< TokenInstance?> -
Get
TokenInstancefrom instance ("default" -> {"default","token1"})override -
getFromToken(
String token) → FutureOr< TokenInstance?> -
Get
TokenInstancefrom token ("token1" -> {"default","token1"})override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String instance) → FutureOr< bool> -
Remove registration for
instanceand returntrueif there are other registrations leftoverride -
removeAll(
) → FutureOr< void> -
override
-
save(
TokenInstance token) → FutureOr< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited