UnifiedPushStorageSharedPreferences class

Inheritance
  • Object
  • UnifiedPushStorage
  • UnifiedPushStorageSharedPreferences

Properties

distrib → DistributorStorage
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
keys → KeysStorage
no setteroverride
registrations → RegistrationsStorage
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init() FutureOr<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited